@@ -267,51 +267,4 @@ pub mod lexer {
             }
         }
     }
-
-    // Unit tests
-    #[cfg(test)]
-    mod unit_test {
-        use super::*;
-
-        #[test]
-        fn test_basic_tokenizer() {
-            let mut tokenizer = Tokenizer::new("Water is healthy!");
-            assert_eq!(tokenizer.next().unwrap(), Token::Word("Water".to_string()));
-            assert_eq!(tokenizer.next().unwrap(), Token::WhiteSpace);
-            assert_eq!(tokenizer.next().unwrap(), Token::Word("is".to_string()));
-            assert_eq!(tokenizer.next().unwrap(), Token::WhiteSpace);
-            assert_eq!(
-                tokenizer.next().unwrap(),
-                Token::Word("healthy".to_string())
-            );
-            assert_eq!(tokenizer.next().unwrap(), Token::Not);
-        }
-
-        #[test]
-        fn test_punctuation_tokenizer() {
-            let mut tokenizer = Tokenizer::new("use super::*;");
-            assert_eq!(tokenizer.next().unwrap(), Token::KW_Use);
-            assert_eq!(tokenizer.next().unwrap(), Token::WhiteSpace);
-            assert_eq!(tokenizer.next().unwrap(), Token::KW_Super);
-            assert_eq!(tokenizer.next().unwrap(), Token::PathSep);
-            assert_eq!(tokenizer.next().unwrap(), Token::Star);
-            assert_eq!(tokenizer.next().unwrap(), Token::Semi);
-        }
-
-        #[test]
-        fn test_numeric_tokenizer() {
-            let mut tokenizer = Tokenizer::new("200 404.4 5_000");
-            assert_eq!(tokenizer.next().unwrap(), Token::Numeric("200".to_string()));
-            assert_eq!(tokenizer.next().unwrap(), Token::WhiteSpace);
-            assert_eq!(
-                tokenizer.next().unwrap(),
-                Token::Floating("404.4".to_string())
-            );
-            assert_eq!(tokenizer.next().unwrap(), Token::WhiteSpace);
-            assert_eq!(
-                tokenizer.next().unwrap(),
-                Token::Floating("5_000".to_string())
-            );
-        }
-    }
 }
